// 在main.js上通过import引入Vue库和自己写的Vue组件库
import Vue from "vue";
import "vant/lib/index.css";
import { Picker } from "vant";
import { Icon } from "vant";
import { Popup } from "vant";

Vue.use(Popup);
Vue.use(Icon);
Vue.use(Picker);

import Customer from "./components/customer.vue";
import eventBus from "../../../../../../util/eventBus";
(function (KDApi) {
  function MyComponent(model) {
    this._setModel(model);
  }

  MyComponent.prototype = {
    _setModel: function (model) {
      this.model = model;
    },
    init: function (props) {
      console.log("===init===", this.model, props);
      setHtml(this.model, props);
    },
    update: function (props) {
      console.log("===update===", this.model, props);
      eventBus.pub(this.model, "update", props);
    },
    destoryed: function () {
      console.log("===destoryed===", this.model);
      localStorage.setItem("selected_customer_id", "");
      eventBus.unsub(this.updateSub);
    },
  };

  const setHtml = (model, props) => {
    const { invoke } = model;

    KDApi.loadFile("./css/index.css", model, () => {
      new Vue({
        el: model.dom,
        template: `<Customer :listData="listData" :selectCount="selectCount" v-on:confirm="confirm"/>`,
        components: {
          Customer,
        },
        data: function () {
          return {
            listData: [],
            selectCount: 0,
          };
        },
        mounted() {
          let self = this;
          this.updateSub = eventBus.sub(model, "update", (data) => {
            self.initData(data);
          });
          self.initData(props);
        },
        methods: {
          initData(props) {
            if (props && props.data) {
              if (props.data.id && props.data.id != "-1") {
                localStorage.setItem("selected_customer_id", props.data.id);
              }

              let selected_customer_id = localStorage.getItem(
                "selected_customer_id"
              );
              //设置勾选状态
              props.data.listData.forEach((item) => {
                if (item.id == selected_customer_id) {
                  item.selected = true;
                } else {
                  item.selected = false;
                }
              });

              this.listData = props.data.listData;
              let tempArr = this.listData.filter((item) => item.selected);
              this.selectCount = tempArr && tempArr.length > 0 ? 1 : 0;
            } else {
              this.listData = [];
              this.selectCount = 0;
            }
          },
          invoke: function (eventName, args) {
            invoke(eventName, args);
          },
          confirm(id) {
            this.invoke("confirm", { id });
          },
        },
      });
    });
  };

  // 注册自定义组件
  KDApi.register("selectCustomerKy", MyComponent);
})(window.KDApi);
